#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lens
version: 4.17
id: lens-4.17-9Q1pWD2BrerLhuespF4bwK
key: lens-4.17-9Q1pWD2BrerLhuespF4bwK
license: BSD-2-Clause
copyright: Copyright (C) 2012-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/lens/
synopsis: Lenses, Folds and Traversals
description:
    This package comes \"Batteries Included\" with many useful lenses for the types
    commonly used from the Haskell Platform, and with tools for automatically
    generating lenses and isomorphisms for user-supplied data types.
    .
    The combinators in @Control.Lens@ provide a highly generic toolbox for composing
    families of getters, folds, isomorphisms, traversals, setters and lenses and their
    indexed variants.
    .
    An overview, with a large number of examples can be found in the <https://github.com/ekmett/lens#lens-lenses-folds-and-traversals README>.
    .
    An introductory video on the style of code used in this library by Simon Peyton Jones is available from <http://skillsmatter.com/podcast/scala/lenses-compositional-data-access-and-manipulation Skills Matter>.
    .
    A video on how to use lenses and how they are constructed is available on <http://youtu.be/cefnmjtAolY?hd=1 youtube>.
    .
    Slides for that second talk can be obtained from <http://comonad.com/haskell/Lenses-Folds-and-Traversals-NYC.pdf comonad.com>.
    .
    More information on the care and feeding of lenses, including a brief tutorial and motivation
    for their types can be found on the <https://github.com/ekmett/lens/wiki lens wiki>.
    .
    A small game of @pong@ and other more complex examples that manage their state using lenses can be found in the <https://github.com/ekmett/lens/blob/master/examples/ example folder>.
    .
    /Lenses, Folds and Traversals/
    .
    With some signatures simplified, the core of the hierarchy of lens-like constructions looks like:
    .
    .
    <<http://i.imgur.com/ALlbPRa.png>>
    .
    <Hierarchy.png (Local Copy)>
    .
    You can compose any two elements of the hierarchy above using @(.)@ from the @Prelude@, and you can
    use any element of the hierarchy as any type it linked to above it.
    .
    The result is their lowest upper bound in the hierarchy (or an error if that bound doesn'\''t exist).
    .
    For instance:
    .
    * You can use any '\''Traversal'\'' as a '\''Fold'\'' or as a '\''Setter'\''.
    .
    * The composition of a '\''Traversal'\'' and a '\''Getter'\'' yields a '\''Fold'\''.
    .
    /Minimizing Dependencies/
    .
    If you want to provide lenses and traversals for your own types in your own libraries, then you
    can do so without incurring a dependency on this (or any other) lens package at all.
    .
    /e.g./ for a data type:
    .
    > data Foo a = Foo Int Int a
    .
    You can define lenses such as
    .
    > -- bar :: Lens'\'' (Foo a) Int
    > bar :: Functor f => (Int -> f Int) -> Foo a -> f (Foo a)
    > bar f (Foo a b c) = fmap (\a'\'' -> Foo a'\'' b c) (f a)
    .
    > -- quux :: Lens (Foo a) (Foo b) a b
    > quux :: Functor f => (a -> f b) -> Foo a -> f (Foo b)
    > quux f (Foo a b c) = fmap (Foo a b) (f c)
    .
    without the need to use any type that isn'\''t already defined in the @Prelude@.
    .
    And you can define a traversal of multiple fields with '\''Control.Applicative.Applicative'\'':
    .
    > -- traverseBarAndBaz :: Traversal'\'' (Foo a) Int
    > traverseBarAndBaz :: Applicative f => (Int -> f Int) -> Foo a -> f (Foo a)
    > traverseBarAndBaz f (Foo a b c) = Foo <$> f a <*> f b <*> pure c
    .
    What is provided in this library is a number of stock lenses and traversals for
    common haskell types, a wide array of combinators for working them, and more
    exotic functionality, (/e.g./ getters, setters, indexed folds, isomorphisms).
category: Data, Lenses, Generics
abi: ab1d1bd95dc58564867100a032286a07
exposed: True
exposed-modules:
    Control.Exception.Lens Control.Lens Control.Lens.At
    Control.Lens.Combinators Control.Lens.Cons Control.Lens.Each
    Control.Lens.Empty Control.Lens.Equality Control.Lens.Extras
    Control.Lens.Fold Control.Lens.Getter Control.Lens.Indexed
    Control.Lens.Internal Control.Lens.Internal.Bazaar
    Control.Lens.Internal.ByteString Control.Lens.Internal.CTypes
    Control.Lens.Internal.Coerce Control.Lens.Internal.Context
    Control.Lens.Internal.Deque Control.Lens.Internal.Exception
    Control.Lens.Internal.FieldTH Control.Lens.Internal.Fold
    Control.Lens.Internal.Getter Control.Lens.Internal.Indexed
    Control.Lens.Internal.Instances Control.Lens.Internal.Iso
    Control.Lens.Internal.Level Control.Lens.Internal.List
    Control.Lens.Internal.Magma Control.Lens.Internal.Prism
    Control.Lens.Internal.PrismTH Control.Lens.Internal.Review
    Control.Lens.Internal.Setter Control.Lens.Internal.TH
    Control.Lens.Internal.Zoom Control.Lens.Iso Control.Lens.Lens
    Control.Lens.Level Control.Lens.Operators Control.Lens.Plated
    Control.Lens.Prism Control.Lens.Reified Control.Lens.Review
    Control.Lens.Setter Control.Lens.TH Control.Lens.Traversal
    Control.Lens.Tuple Control.Lens.Type Control.Lens.Unsound
    Control.Lens.Wrapped Control.Lens.Zoom Control.Monad.Error.Lens
    Control.Parallel.Strategies.Lens Control.Seq.Lens Data.Array.Lens
    Data.Bits.Lens Data.ByteString.Lazy.Lens Data.ByteString.Lens
    Data.ByteString.Strict.Lens Data.Complex.Lens Data.Data.Lens
    Data.Dynamic.Lens Data.HashSet.Lens Data.IntSet.Lens Data.List.Lens
    Data.Map.Lens Data.Sequence.Lens Data.Set.Lens Data.Text.Lazy.Lens
    Data.Text.Lens Data.Text.Strict.Lens Data.Tree.Lens
    Data.Typeable.Lens Data.Vector.Generic.Lens Data.Vector.Lens
    GHC.Generics.Lens Language.Haskell.TH.Lens Numeric.Lens
    Numeric.Natural.Lens System.Exit.Lens System.FilePath.Lens
    System.IO.Error.Lens
hidden-modules: Paths_lens
import-dirs: /usr/lib/ghc-8.4.3/site-local/lens-4.17
library-dirs: /usr/lib/ghc-8.4.3/site-local/lens-4.17
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/lens-4.17
hs-libraries: HSlens-4.17-9Q1pWD2BrerLhuespF4bwK
depends:
    array-0.5.2.0 base-4.11.1.0 base-orphans-0.8-IMe9IACIp8aFSEynTCteC2
    bifunctors-5.5.3-9jqaoheYI3yJSBk86s0M4s bytestring-0.10.8.2
    call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq
    comonad-5.0.4-6EAk2fiOHry3dCQFwOV2DJ
    contravariant-1.5-5VBqEYOPGpyDW8QIali4BA containers-0.5.11.0
    distributive-0.6-2KZpFXarf2vK5nBSXPMPgm filepath-1.4.2
    free-5.1-BFtmHBhyfaY9oeZhCqiXSW ghc-prim-0.5.2.0
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    kan-extensions-5.2-2n18kljG5oOEshHxriazpu
    exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8 mtl-2.2.2
    parallel-3.2.2.0-E8M4t2NF24XDDNAVbYCukS
    profunctors-5.3-EyaevEeToBAINHHYFRofUu
    reflection-2.1.4-ET4Qfoy5lmWBopRK3ezJIQ
    semigroupoids-5.3.1-75rtBVl2clEGbLMbIolsCS
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO template-haskell-2.13.0.0
    th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88 text-1.2.3.0
    transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    unordered-containers-0.2.9.0-HNWXUV6vCRnCav4TlSGszj
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    void-0.7.2-JAsenjnj1DBHDal2sW0JoW
abi-depends: array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-orphans-0.8-IMe9IACIp8aFSEynTCteC2=9d1eb5b04157e6a04f0c8e24c12b6390
             bifunctors-5.5.3-9jqaoheYI3yJSBk86s0M4s=3d3c9e00ff840d6fb7ed94064910112e
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq=842aa1f6a3dc6ac6e201dfeb465a9bd8
             comonad-5.0.4-6EAk2fiOHry3dCQFwOV2DJ=33f3aad5ccd0483535d25476e9626028
             contravariant-1.5-5VBqEYOPGpyDW8QIali4BA=e9f0d327bd08c2672bd55840cd3b39db
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             distributive-0.6-2KZpFXarf2vK5nBSXPMPgm=4365458f993e4724719abaae53d87603
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             free-5.1-BFtmHBhyfaY9oeZhCqiXSW=8439151d22fde1628620ded87e0d0324
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             kan-extensions-5.2-2n18kljG5oOEshHxriazpu=06313c0ffd72c18e1504983a99e84665
             exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8=e9779fb859fee3584d68df46d12eac41
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             parallel-3.2.2.0-E8M4t2NF24XDDNAVbYCukS=8817dbddef9879e3e8c45cfc95d59bc0
             profunctors-5.3-EyaevEeToBAINHHYFRofUu=890e3f1854c4ec6e22fcd5beda192e9a
             reflection-2.1.4-ET4Qfoy5lmWBopRK3ezJIQ=9287f3432288cf494e6469a0d7445dde
             semigroupoids-5.3.1-75rtBVl2clEGbLMbIolsCS=a6f845a23e924c054d844fb1f6531903
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
             th-abstraction-0.2.8.0-Ct896m4STpK8GA15Cl5y88=303b2de9b3dc2b2e86b6ff0f8de41846
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=197a030c492741542d6f49bc76370bb8
             unordered-containers-0.2.9.0-HNWXUV6vCRnCav4TlSGszj=c333847eb697e0b9a0c6f4333fc78402
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=2d4c17574909e037fa0256847c747647
             void-0.7.2-JAsenjnj1DBHDal2sW0JoW=f14401e2229f003d6e8153beb939779e
haddock-interfaces: /usr/share/doc/haskell-lens/html/lens.haddock
haddock-html: /usr/share/doc/haskell-lens/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

